use json;
use r2d2::{ManageConnection, Pool, PooledConnection};
use std::sync::{Arc, Mutex};
use crate::{get_backend, BackendClient};

static ENDPOINTS: [(&str, fn(json::JsonValue) -> json::JsonValue); 1] = [
    ("echo", echo)
];

pub fn is_valid_endpoint(endpoint: &str) -> bool {
    for (name, _func) in &ENDPOINTS {
        if endpoint.eq(*name) {
            return true;
        }
    }
    false
}

pub fn endpoint(endpoint: &str, input: json::JsonValue) -> json::JsonValue {
    for (name, func) in &ENDPOINTS {
        if endpoint.eq(*name) {
            return func(input);
        }
    }
    panic!("invalid endpoint, check with is_valid_endpoint")
}

pub fn echo(input: json::JsonValue) -> json::JsonValue {
    let backend = get_backend();
    let mut output = input.clone();
    match backend {
        BackendClient::Postgres(mut client) => {
            let res = client.query("SELECT * FROM test", &[]).unwrap();
            for row in res {
                let val: i32 = row.get(0);
                output["database"] = val.into();
            }
        }
    }
    output
}
